==> order-base-1.0.20201114.074547-63-sources.jar: com/rocogz/syy/order/entity/goods/GoodsOrder.java <==
package com.rocogz.syy.order.entity.goods;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.rocogz.syy.common.annotation.UniqueField;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <p>
 * 订单中心-商品订单
 * </p>
 *
 * @author ranxiangfu
 * @since 2020-08-18
 */
@Setter @Getter
@Accessors(chain = true)
@TableName("order_goods_order")
public class GoodsOrder extends IdEntity {

    private static final long serialVersionUID = -6947173409061140577L;

    /**
     * 订单编号
     */
    @UniqueField
    private String orderCode;

    /**
     * 用户编号
     */
    private String userCode;

    /**
     * 是否虚拟商品
     */
    private Boolean virtual;

    /**
     * 虚拟商品类型：卡券(CARD)、 充值(DEPOSIT)、 碎屏险(SCREEN_CRASH_INSURANCE)、 电池券/换壳券(COUPON)、 EXTENSION_INSURANCE(手机延保服务)
     */
    private String virtualType;

    /**
     * 商品供应商编号
     */
    private String supplierCode;

    /**
     * 商品供应商名称
     */
    private String supplierName;

    /**
     * sku编号
     */
    private String skuCode;

    /**
     * 主商品编号
     */
    private String goodCode;

    /**
     * 主商品名称
     */
    private String goodName;

    /**
     * 该商品是否支持花呗分期付款,订单详情发起再次支付时使用
     */
    private Boolean pcreditSupported;

    /**
     * 白色,xl
     */
    private String attrValues;

    /**
     * 商品展示图片url
     */
    private String pictureUrl;

    /**
     * 商品支付方式: 纯积分(CENT)、现金抵扣积分(CASH_DEDUCTION)、固定积分+固定现金(CENT_WITH_CASH)
     */
    private String goodPayWay;

    /**
     * 积分价
     * （1）"纯积分"支付方式：纯积分
     * （2）"现金抵扣兑换"支付方式：总积分
     * （3）"固定积分+固定现金"支付方式： 固定积分
     */
    private BigDecimal cent;

    /**
     * "现金抵扣兑换"支付方式下：需支付的最少积分
     */
    private BigDecimal minCent;

    /**
     *
     * "固定积分+固定现金" 支付方式下：固定现金价
     */
    private BigDecimal cash;


    /**
     * 商品购买数量
     */
    private Integer quantity;

    /**
     * 充值手机号：如果购买的是 充值虚拟商品(话费,流量)
     */
    private String depositMobile;

    /**
     * 需支付订单现金金额[现金部分]
     */
    private BigDecimal totalCash;

    /**
     * 需支付订单积分 [积分部分]
     */
    private BigDecimal totalCent;

    /**
     * 快递名称
     */
    private String expressDeliveryName;

    /**
     * 快递单号
     */
    private String expressDeliveryNumber;

    /**
     * 发货时间
     */
    private LocalDateTime sendTime;

    /**
     * 确认收货时间
     */
    private LocalDateTime receiveTime;

    /**
     * 完成时间
     */
    private LocalDateTime finishTime;

    /**
     * 商品订单支付模式 (POINT:积分;  CASH:现金; POINT_AND_CASH:积分+现金)
     * @see com.rocogz.syy.order.constant.OrderConstant.DictGoodsOrderPayWay
     */
    private String payWay;


    /**
     * 最终成功支付的 现金使用的支付方式：微信/支付宝
     * @see com.rocogz.syy.order.constant.OrderConstant.DictPayWay
     */
    private String cashPayWay;



    // 三星生活助手订单,线上下单模式(碎屏险,手机延保服务)
    private String samsungCouponCode;
    private String samsungCouponType;


    //三星生活助手订单,下线模式下单 发票信息
    /**
     * 发票抬头：北京吉祥如意科技股份有限公司
     */
    private String invoiceTitle;

    /**
     * 发票抬头类型：单位/个人
     */
    private String invoiceTileType;

    /**
     * 发票类型：增值税专用发票/普通发票
     */
    private String invoiceType;

    /**
     * 发票内容：住宿费
     */
    private String invoiceContent;

    /**
     *接收发票信息的邮箱
     */
    private String  invoiceEmail;



    /**
     * 备注
     */
    private String remark;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 创建人
     */
    private String createUser;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 更新人
     */
    private String updateUser;

    /**
     * 收货地址信息[非虚拟商品才有收货地址]
     */
    @TableField(exist = false)
    private GoodsOrderDeliveryAddress goodsOrderDeliveryAddress;



    //hhl增加,为了直观判断是否能再次售后
    //adminSearch 售后操作 按钮判断
    @TableField(exist = false)
    private String afterCode;

}

==> order-base-1.0.20201116.104157-70-sources.jar: com/rocogz/syy/order/entity/goods/GoodsOrder.java <==
package com.rocogz.syy.order.entity.goods;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.rocogz.syy.common.annotation.UniqueField;
import com.rocogz.syy.common.entity.IdEntity;
import lombok.Getter;
import lombok.Setter;
import lombok.experimental.Accessors;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <p>
 * 订单中心-商品订单
 * </p>
 *
 * @author ranxiangfu
 * @since 2020-08-18
 */
@Setter @Getter
@Accessors(chain = true)
@TableName("order_goods_order")
public class GoodsOrder extends IdEntity {

    private static final long serialVersionUID = -6947173409061140577L;

    /**
     * 订单编号
     */
    @UniqueField
    private String orderCode;

    /**
     * 用户编号
     */
    private String userCode;

    /**
     * 是否虚拟商品
     */
    private Boolean virtual;

    /**
     * 虚拟商品类型：卡券(CARD)、 充值(DEPOSIT)、 碎屏险(SCREEN_CRASH_INSURANCE)、 电池券/换壳券(COUPON)、 EXTENSION_INSURANCE(手机延保服务)
     */
    private String virtualType;

    /**
     * 商品供应商编号
     */
    private String supplierCode;

    /**
     * 商品供应商名称
     */
    private String supplierName;

    /**
     * sku编号
     */
    private String skuCode;

    /**
     * 主商品编号
     */
    private String goodCode;

    /**
     * 主商品名称
     */
    private String goodName;

    /**
     * 该商品是否支持花呗分期付款,订单详情发起再次支付时使用
     */
    private Boolean pcreditSupported;

    /**
     * 白色,xl
     */
    private String attrValues;

    /**
     * 商品展示图片url
     */
    private String pictureUrl;

    /**
     * 商品支付方式: 纯积分(CENT)、现金抵扣积分(CASH_DEDUCTION)、固定积分+固定现金(CENT_WITH_CASH)
     */
    private String goodPayWay;

    /**
     * 积分价
     * （1）"纯积分"支付方式：纯积分
     * （2）"现金抵扣兑换"支付方式：总积分
     * （3）"固定积分+固定现金"支付方式： 固定积分
     */
    private BigDecimal cent;

    /**
     * "现金抵扣兑换"支付方式下：需支付的最少积分
     */
    private BigDecimal minCent;

    /**
     *
     * "固定积分+固定现金" 支付方式下：固定现金价
     */
    private BigDecimal cash;


    /**
     * 商品购买数量
     */
    private Integer quantity;

    /**
     * 充值手机号：如果购买的是 充值虚拟商品(话费,流量)
     */
    private String depositMobile;

    /**
     * 需支付订单现金金额[现金部分]
     */
    private BigDecimal totalCash;

    /**
     * 需支付订单积分 [积分部分]
     */
    private BigDecimal totalCent;

    /**
     * 快递名称
     */
    private String expressDeliveryName;

    /**
     * 快递单号
     */
    private String expressDeliveryNumber;

    /**
     * 发货时间
     */
    private LocalDateTime sendTime;

    /**
     * 确认收货时间
     */
    private LocalDateTime receiveTime;

    /**
     * 完成时间
     */
    private LocalDateTime finishTime;

    /**
     * 商品订单支付模式 (POINT:积分;  CASH:现金; POINT_AND_CASH:积分+现金)
     * @see com.rocogz.syy.order.constant.OrderConstant.DictGoodsOrderPayWay
     */
    private String payWay;


    /**
     * 最终成功支付的 现金使用的支付方式：微信/支付宝
     * @see com.rocogz.syy.order.constant.OrderConstant.DictPayWay
     */
    private String cashPayWay;


    // 三星生活助手订单,线上下单模式(碎屏险,手机延保服务)
    private String samsungCouponCode;
    private String samsungCouponType;

    /**
     * 支付结果是否通知成功到 三星生活助手
     */
   // private Boolean notifySucceed;

    /**
     * 支付结果通知三星生活助手 失败后尝试次数：最多尝试5次,不包括第一次
     */
   // private Integer notifyRetryTimes;

    /**
     * 支付结果通知三星生活助手 失败原因
     */
   // private String notifyFailReason;

    /**
     * 支付结果通知：最后一次尝试时间
     */
   // private LocalDateTime notifyLastRetryTime;



    //三星生活助手订单,下线模式下单 发票信息
    /**
     * 发票抬头：北京吉祥如意科技股份有限公司
     */
    private String invoiceTitle;

    /**
     * 发票抬头类型：单位/个人
     */
    private String invoiceTileType;

    /**
     * 发票类型：增值税专用发票/普通发票
     */
    private String invoiceType;

    /**
     * 发票内容：住宿费
     */
    private String invoiceContent;

    /**
     *接收发票信息的邮箱
     */
    private String  invoiceEmail;


    /**
     * 备注
     */
    private String remark;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 创建人
     */
    private String createUser;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 更新人
     */
    private String updateUser;

    /**
     * 收货地址信息[非虚拟商品才有收货地址]
     */
    @TableField(exist = false)
    private GoodsOrderDeliveryAddress goodsOrderDeliveryAddress;




}
